summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmobjectselect.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmobjectselect.h')
-rw-r--r--kpovmodeler/pmobjectselect.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kpovmodeler/pmobjectselect.h b/kpovmodeler/pmobjectselect.h
index c8604eb4..8ef83583 100644
--- a/kpovmodeler/pmobjectselect.h
+++ b/kpovmodeler/pmobjectselect.h
@@ -87,9 +87,9 @@ class PMObjectSelect : public KDialogBase
TQ_OBJECT
public:
/**
* Creates a selection widget with tqparent and name
*/
- PMObjectSelect( TQWidget* tqparent = 0, const char* name = 0,
+ PMObjectSelect( TQWidget* parent = 0, const char* name = 0,
bool modal = true );
/**
* Deletes the dialog
@@ -113,13 +113,13 @@ public:
* Only objects above the object link are listed.
*/
static int selectObject( PMObject* link, const TQString& t, PMObject* & obj,
- TQWidget* tqparent = 0 );
+ TQWidget* parent = 0 );
static int selectObject( PMObject* link, const TQStringList& t,
- PMObject* & obj, TQWidget* tqparent = 0 );
+ PMObject* & obj, TQWidget* parent = 0 );
static int selectDeclare( PMObject* link, const TQString& declareType,
- PMObject* & obj, TQWidget* tqparent = 0 );
+ PMObject* & obj, TQWidget* parent = 0 );
static int selectDeclare( PMObject* link, const TQStringList& dt,
- PMObject* & obj, TQWidget* tqparent = 0 );
+ PMObject* & obj, TQWidget* parent = 0 );
protected slots:
void slotHighlighted( TQListBoxItem* lbi );
@@ -87,9 +87,9 @@ class PMObjectSelect : public KDialogBase
public:
/**
- * Creates a selection widget with tqparent and name
+ * Creates a selection widget with parent and name
*/